"use client";

import React, { useContext, useEffect, useRef, useState } from "react";
import { BottomSheet } from "react-spring-bottom-sheet";
import Input from "plugins/Input/page";
import AppContext from "@ctx/AppContext";
import SimpleReactValidator from "simple-react-validator";
import { toast } from "react-toastify";
import Buttonbriz from "plugins/Buttonbriz/page";

const BottomSheetCreateSection = (props) => {
  const CTX = useContext(AppContext);
  const [title, setTitle] = useState("");
  const [description, setDescription] = useState("");

  const [, forceUpdate] = useState();

  const validator = useRef(
    new SimpleReactValidator({
      messages: {
        required: "پر کردن این فیلد الزامی میباشد",
      },
      element: (message) => (
        <>
          <div className="text-right px-1 ">
            <small className="text-red-600 t-ig-small  ">{message}</small>
          </div>
        </>
      ),
    })
  );

  const goToEditSection = CTX.state.goToEditSection;
  const idEditSection = CTX.state.idEditSection;
  const sectionData = CTX.state.sectionData;

  const body = {
    description,
    title,
  };

  const bodyUpdate = {
    description,
    title,
    id: idEditSection,
  };

  console.log(bodyUpdate);

  const clear = () => {
    setTitle("");
    setDescription("");
  };

  const handleCreateSection = (update) => {
    if (validator.current.allValid()) {
      if (update == "UPDATE") {
        CTX.UpdateSection(bodyUpdate);
      } else {
        CTX.CreateSection(body);
      }
    } else {
      toast.error("پرکردن همه ی فیلد ها واجب است", {
        position: "bottom-right",
        autoClose: 2000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });

      validator.current.showMessages();
      forceUpdate(1);
    }
  };

  const handleBottomSheetCreateSectionOpen = (e) => {
    if (e.type == "OPEN") {
      if (goToEditSection) {
        CTX.GetSection(idEditSection);
      }
    } else if (e.type == "CLOSE") {
      clear();
      CTX.setGoToEditSection(false);
      CTX.setIdEditSection(null);
      CTX.setSectionData([]);
    }
  };

  useEffect(() => {
    if (goToEditSection) {
      setTitle(sectionData.name);
      setDescription(sectionData.description);
      console.log("sectionData", sectionData);
    }
  }, [sectionData]);

  return (
    <BottomSheet
      onSpringStart={(e) => handleBottomSheetCreateSectionOpen(e)}
      open={CTX.state.BottomSheetCreateSectionOpen}
      onDismiss={() => CTX.setBottomSheetCreateSectionOpen(false)}
      blocking={false}
    >
      <div className="text-center py-2 bg-primary-300  ">
        <p className="mb-0 text-white relative top-[-5px]">افزودن سکشن جدید </p>
      </div>

      <div className="bg-body-100 p-4 ">
        <div className="">
          <Input
            lable="نام سکشن "
            id="title-id"
            name="title"
            type={"text"}
            value={title}
            inputEvent={(e) => {
              setTitle(e.target.value);
              validator.current.showMessageFor("title");
            }}
            style="text-right"
            validator={true}
            validatorData={validator.current.message(
              "title",
              title,
              "required"
            )}
          />
        </div>
        <div className="">
          <Input
            lable=" توضیحات"
            id="description-id"
            name="description"
            type={"text"}
            value={description}
            inputEvent={(e) => {
              setDescription(e.target.value);
              validator.current.showMessageFor("description");
            }}
            textarea={true}
            style="text-right"
            validator={true}
            validatorData={validator.current.message(
              "description",
              description,
              "required"
            )}
          />
        </div>

        {goToEditSection ? (
          <Buttonbriz
            title="ویرایش سکشن"
            color="INFO"
            icon="CHECK"
            buttonEvent={() => handleCreateSection("UPDATE")}
            subButton={true}
            subButtonTitle="حذف سکشن"
            subButtonEvent={() => CTX.DeleteSection(idEditSection)}
          />
        ) : (
          <Buttonbriz
            title="ثبت سکشن"
            color="PRIMARY"
            icon="CHECK"
            buttonEvent={() => handleCreateSection()}
          />
        )}
      </div>
    </BottomSheet>
  );
};

export default BottomSheetCreateSection;
